@@ -39,11 +39,6 @@ def path_to_url(path: Path) -> URL:
     return URL(f'file://{path}')
 
 
-def path_to_iri(path: Path) -> URIRef:
-    """Create a usable graph IRI for a path."""
-    return URIRef(f'file://{path}')
-
-
 def url_to_path(url: URL) -> Path:
     """Convert a file:// URL into a UNIX path."""
     return Path(url.path)
