@@ -1,10 +1,10 @@
 from dataclasses import dataclass
 from functools import cached_property
-from typing import Optional
+from typing import Optional, Union
 
 from ldflex import LDFlex
 from octadocs.octiron import Octiron
-from rdflib.term import Node, URIRef
+from rdflib.term import Node, URIRef, BNode
 
 
 @dataclass
@@ -21,8 +21,11 @@ class Facet:
         return self.octiron.ldflex
 
     @cached_property
-    def uriref(self) -> URIRef:
+    def uriref(self) -> Union[URIRef, BNode]:
         """Format as URIRef."""
+        if isinstance(self.iri, BNode):
+            return self.iri
+
         return URIRef(self.iri)
 
     def query(self, query_text: str, **kwargs):
@@ -36,6 +39,10 @@ class Facet:
         """Render the facet."""
         raise NotImplementedError()
 
+    @property
+    def language(self):
+        return self.octiron.language
+
     def __str__(self):
         """Render."""
         return str(self.render())
