@@ -1,6 +1,6 @@
 from mkdocs.config import load_config
 from more_itertools import consume
-from octadocs.cli import context, sparql
+from octadocs.cli import context, sparql, show
 from typer import Typer
 
 
@@ -9,6 +9,7 @@ def generate_app() -> Typer:
 
     app.add_typer(sparql.app)
     app.add_typer(context.app)
+    app.add_typer(show.app)
 
     config = load_config()
 
