@@ -9,7 +9,7 @@ class DateLiteral(Facet):
     """Render a date."""
 
     def render(self):
-        """Render as icon."""
+        """Render date or datetime as a date."""
         literal = cast(Literal, self.iri)
 
         date_value = literal.value
