@@ -4,27 +4,34 @@ Iolanta facet management.
 This module contains a few functions which later will be refactored into
 Iolanta - the generic metaverse/cyberspace browser.
 """
-import operator
 import pydoc
+import random
 from dataclasses import dataclass
-from typing import Callable, Iterable, List, Optional, Union
+from pathlib import Path
+from typing import Iterable, List, Optional, Union, Type
+
+from dominate.tags import (
+    div, small, code, br, span, strong, b, font, table,
+    tr, td,
+)
+from dominate.util import raw
+from rdflib.term import Literal, Node, URIRef
 
 from iolanta.facet import Facet
 from iolanta.facets.base import FacetSearchAttempt
 from iolanta.facets.by_environment import FindFacetByEnvironment
 from iolanta.facets.by_instance import FindFacetByInstance
 from iolanta.facets.by_literal_datatype import FindFacetByLiteralDatatype
-from iolanta.facets.by_type import FindFacetByType
+from iolanta.facets.by_type import FindFacetByInstanceTypes
+from iolanta.facets.for_literal import FindFacetForLiteral
 from ldflex import LDFlex
 from octadocs.iolanta.errors import FacetError, FacetNotCallable, FacetNotFound
 from octadocs.octiron import Octiron
-from rdflib import RDFS
-from rdflib.term import Literal, Node, URIRef
 
 HTML = URIRef('https://html.spec.whatwg.org/')
 
 
-def resolve_facet(iri: URIRef) -> Callable[[Octiron, Node], str]:
+def resolve_facet(iri: URIRef) -> Type[Facet]:
     """Resolve a path to a Python object to that object."""
     url = str(iri)
 
@@ -54,12 +61,53 @@ def resolve_facet(iri: URIRef) -> Callable[[Octiron, Node], str]:
     return facet
 
 
+def _render_facet(
+    node: Node,
+    facet: Facet,
+    environments: Optional[List[URIRef]] = None,
+    debug_mode: bool = False,
+):
+    if debug_mode:
+        return debug_node(
+            node=node,
+            environments=environments,
+        )
+
+    return facet.render()
+
+
+def debug_node(node: Union[str, Node], environments: Optional[List[URIRef]]):
+    return table(
+        tr(
+            td(
+                b(font('Debug', color='red')),
+                colspan=2,
+                border=0,
+            ),
+        ),
+        tr(
+            td(b(font('Node', color='red')), border=0, align='left'),
+            td(str(node), border=0, align='left'),
+        ),
+        tr(
+            td(b(font('Environments', color='red')), border=0, align='left'),
+            td(', '.join(
+                map(str, environments),
+            ), border=0, align='left'),
+        ),
+        border=1,
+    )
+
+
 def render(
     node: Union[str, Node],
     octiron: Octiron,
     environments: Optional[List[URIRef]] = None,
 ) -> str:
     """Find an Iolanta facet for a node and render it."""
+    if isinstance(environments, str):
+        environments = [environments]
+
     if not environments:
         environments = [HTML]
 
@@ -70,33 +118,38 @@ def render(
         environments=environments,
     )
 
-    facet = resolve_facet(
+    facet_class = resolve_facet(
         iri=facet_search_attempt.facet,
     )
 
-    facet = facet(
+    if not issubclass(facet_class, Facet):
+        raise ValueError(f'{facet_class} is not a Facet.')
+
+    facet = facet_class(
         iri=node,
         octiron=octiron,
         environment=facet_search_attempt.environment,
     )
 
-    if isinstance(facet, Facet):
-        try:
-            return facet.render()
+    try:
+        return _render_facet(
+            node=node,
+            facet=facet,
+            environments=environments,
+            debug_mode=octiron.is_debug_mode(node),
+        )
 
-        except (FacetError, FacetNotFound):   # noqa: WPS329
-            # Prevent nested `FacetError` exceptions.
-            raise
+    except (FacetError, FacetNotFound):   # noqa: WPS329
+        # Prevent nested `FacetError` exceptions.
+        raise
 
-        except Exception as err:
-            raise FacetError(
-                node=node,
-                facet_iri=facet_search_attempt.facet,
-                facet_search_attempt=facet_search_attempt,
-                error=err,
-            ) from err
-
-    return facet
+    except Exception as err:
+        raise FacetError(
+            node=node,
+            facet_iri=facet_search_attempt.facet,
+            facet_search_attempt=facet_search_attempt,
+            error=err,
+        ) from err
 
 
 @dataclass
@@ -182,14 +235,11 @@ class Render:
             environment=environment,
         )
 
-        instance_types = self.find_instance_types(node)
-        for instance_type in instance_types:
-            yield FindFacetByType(
-                ldflex=self.ldflex,
-                node=node,
-                environment=environment,
-                instance_type=instance_type,
-            )
+        yield FindFacetByInstanceTypes(
+            ldflex=self.ldflex,
+            node=node,
+            environment=environment,
+        )
 
         yield FindFacetByEnvironment(
             ldflex=self.ldflex,
@@ -213,11 +263,10 @@ class Render:
                 environment=environment,
             )
 
-        yield FindFacetByType(
+        yield FindFacetForLiteral(
             ldflex=self.ldflex,
             node=literal,
             environment=environment,
-            instance_type=RDFS.Literal,
         )
 
         yield FindFacetByEnvironment(
@@ -225,21 +274,3 @@ class Render:
             node=literal,
             environment=environment,
         )
-
-    def find_instance_types(self, node: URIRef) -> List[URIRef]:
-        """Find types for particular node."""
-        rows = self.ldflex.query(
-            query_text='''
-            SELECT ?type WHERE {
-                $node rdf:type ?type .
-            }
-            ''',
-            node=node,
-        )
-
-        return list(
-            map(
-                operator.itemgetter('type'),
-                rows,
-            ),
-        )
