@@ -1,3 +1,4 @@
+import copy
 import logging
 import sys
 from dataclasses import dataclass, field
@@ -5,9 +6,12 @@ from enum import Enum, auto
 from functools import reduce
 from pathlib import Path
 from types import MappingProxyType
-from typing import Any, Dict, Iterable, Optional
+from typing import Any, Dict, Iterable, Optional, Set
 
+import funcy
 import rdflib
+from rdflib.term import Node
+
 from iolanta.context import merge
 from iolanta.loaders.local_file import IsAContext, ParserNotFound
 from iolanta.models import LDContext
@@ -65,6 +69,7 @@ class Octiron:  # noqa: WPS214
     """
 
     root_directory: Path
+    language: str
     custom_namespaces: Dict[str, rdflib.Namespace] = field(default_factory=dict)
     last_modified_timestamp_per_file: Dict[rdflib.URIRef, float] = field(
         default_factory=dict,
@@ -170,7 +175,7 @@ class Octiron:  # noqa: WPS214
             quads = as_quad_stream(
                 url=URL(f'file://{path}'),
                 iri=local_iri,
-                default_context=self.root_context,
+                default_context=copy.deepcopy(self.root_context),
                 root_directory=self.root_directory,
                 named_contexts=named_contexts,
             )
@@ -324,3 +329,15 @@ class Octiron:  # noqa: WPS214
             path=self.root_directory.parent / '.cache/octadocs',
         )
         logger.info('Saved graph to disk for CLI to use.')
+
+    @cached_property
+    def debugging_nodes(self) -> Set[Node]:
+        return set(
+            funcy.pluck(
+                'node',
+                self.query('SELECT * WHERE { ?node octa:debug true }'),
+            ),
+        )
+
+    def is_debug_mode(self, node: Node) -> bool:
+        return node in self.debugging_nodes
