@@ -127,7 +127,6 @@ class OctaDocsPlugin(BasePlugin):
                     'iolanta/named-context.json',
                 ),
                 'owl': self.retrieve_named_context('owl/named-context.json'),
-                # 'octa': self.retrieve_named_context('octa/named-context.json'),
             },
         })
 
@@ -152,12 +151,15 @@ class OctaDocsPlugin(BasePlugin):
         )
 
         for mkdocs_file in files:
-            self.octiron.update_from_file(
-                path=Path(mkdocs_file.abs_src_path),
-                local_iri=src_path_to_iri(mkdocs_file.src_path),
-                global_url=f'/{mkdocs_file.url}',
-                named_contexts=config['extra']['named_contexts'],
-            )
+            path = Path(mkdocs_file.abs_src_path)
+
+            if path.is_relative_to(self.octiron.root_directory):
+                self.octiron.update_from_file(
+                    path=path,
+                    local_iri=src_path_to_iri(mkdocs_file.src_path),
+                    global_url=f'/{mkdocs_file.url}',
+                    named_contexts=config['extra']['named_contexts'],
+                )
 
     def on_page_markdown(
         self,
