@@ -1,4 +1,5 @@
 import operator
+from pathlib import Path
 from typing import List, Optional, TypedDict
 
 from dominate.tags import li, table, tbody, td, th, thead, tr, ul
@@ -45,28 +46,9 @@ class ColumnLegend(Facet):
     be thereupon refactored.
     """
 
-    legend_query = '''
-    SELECT ?prov_value ?comment (COUNT(?prov_value) AS ?count) WHERE {
-        ?instance $column ?node .
-
-        {
-            FILTER isLiteral(?node) .
-        } UNION {
-            FILTER (isIRI(?node) || isBlank(?node)) .
-            ?node prov:value+ ?prov_value .
-
-            OPTIONAL {
-                {
-                    ?prov_value rdfs:comment ?comment .
-                } UNION {
-                    ?node rdfs:comment ?comment .
-                }
-            }
-        }
-    }
-    GROUP BY ?prov_value ?comment
-    ORDER BY DESC(?count)
-    '''
+    legend_query = (
+        Path(__file__).parent / 'sparql/legend.sparql'
+    ).read_text()
 
     def render_comment(self, row: Row):
         """Render description column."""
@@ -75,7 +57,7 @@ class ColumnLegend(Facet):
         if comment:
             yield raw(comment)
 
-        if row['prov_value'] is None:
+        if row.get('prov_value') is None:
             return
 
         see_also_links = list(
@@ -126,11 +108,11 @@ class ColumnLegend(Facet):
                                 TABLE.td,
                                 IOLANTA.html,
                             ],
-                        ) if row['prov_value'] is not None else '',
+                        ) if row.get('prov_value') is not None else '',
                     ),
                 ),
                 td(*self.render_comment(row)),
-                td(row['count']),
+                td(row.get('count', '')),
             )
             for row in rows
         ]
